.. _datasets:

=============
Data Sets
=============

This is the documentation for available datasets.

Rainbow Beach
-------------
.. autofunction:: sam.datasets.load_rainbow_beach


Sewage data
-----------
.. autofunction:: sam.datasets.load_sewage_data


